@@ -105,6 +105,18 @@ print_it($F,'Color Mapping Test -> Red-Green-Blue');
             'height' => $YY
         }
     );
+#    sleep $factor;
+    $image = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => 0,
+            'width'  => $XX * .75,
+            'height' => ($YY - $F->{'Y_CLIP'}) * .75,
+            'center' => 3,
+            'file'   => 'images/testpattern.jpg'
+        }
+    );
+    $F->blit_write($image);
     sleep $factor;
 }
 
@@ -251,24 +263,24 @@ while (time < $s) {
     $F->box(
         {
             'x'        => rand($XX),
-              'y'        => rand($YY),
-              'xx'       => rand($XX),
-              'yy'       => rand($YY),
-              'radius'   => rand($XX / 16),
-              'filled'   => 1,
-              'gradient' => {
-                  'direction' => 'horizontal',
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'        => rand($YY),
+            'xx'       => rand($XX),
+            'yy'       => rand($YY),
+            'radius'   => rand($XX / 16),
+            'filled'   => 1,
+            'gradient' => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
 } ## end while (time < $s)
@@ -294,21 +306,21 @@ while (time < $s) {
     $F->circle(
         {
             'x'        => rand($XX),
-              'y'        => rand($YY),
-              'radius'   => rand($center_y),
-              'filled'   => 1,
-              'gradient' => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'        => rand($YY),
+            'radius'   => rand($center_y),
+            'filled'   => 1,
+            'gradient' => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
 } ## end while (time < $s)
@@ -320,22 +332,22 @@ while (time < $s) {
     $F->circle(
         {
             'x'        => rand($XX),
-              'y'        => rand($YY),
-              'radius'   => rand($center_y),
-              'filled'   => 1,
-              'gradient' => {
-                  'direction' => 'horizontal',
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'        => rand($YY),
+            'radius'   => rand($center_y),
+            'filled'   => 1,
+            'gradient' => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
 } ## end while (time < $s)
@@ -368,22 +380,22 @@ while (time < $s) {
     $F->filled_pie(
         {
             'x'             => rand($XX),
-              'y'             => rand($YY),
-              'radius'        => rand($center_y),
-              'start_degrees' => rand(360),
-              'end_degrees'   => rand(360),
-              'gradient'      => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'             => rand($YY),
+            'radius'        => rand($center_y),
+            'start_degrees' => rand(360),
+            'end_degrees'   => rand(360),
+            'gradient'      => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
 } ## end while (time < $s)
@@ -409,22 +421,22 @@ while (time < $s) {
     $F->ellipse(
         {
             'x'        => rand($XX),
-              'y'        => rand($YY),
-              'xradius'  => rand($center_x),
-              'yradius'  => rand($center_y),
-              'filled'   => 1,
-              'gradient' => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'        => rand($YY),
+            'xradius'  => rand($center_x),
+            'yradius'  => rand($center_y),
+            'filled'   => 1,
+            'gradient' => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
 } ## end while (time < $s)
@@ -436,23 +448,23 @@ while (time < $s) {
     $F->ellipse(
         {
             'x'        => rand($XX),
-              'y'        => rand($YY),
-              'xradius'  => rand($center_x),
-              'yradius'  => rand($center_y),
-              'filled'   => 1,
-              'gradient' => {
-                  'direction' => 'horizontal',
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'        => rand($YY),
+            'xradius'  => rand($center_x),
+            'yradius'  => rand($center_y),
+            'filled'   => 1,
+            'gradient' => {
+                'direction' => 'horizontal',
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
 } ## end while (time < $s)
@@ -478,19 +490,19 @@ while (time < $s) {
     $F->polygon(
         {
             'coordinates' => [rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY)],
-              'filled'      => 1,
-              'gradient'    => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'filled'      => 1,
+            'gradient'    => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
 } ## end while (time < $s)
@@ -520,13 +532,13 @@ while (time < $s) {
         my $b = $F->ttf_print(
             {
                 'x'            => $x,
-                  'y'            => $y,
-                  'height'       => $h,
-                  'wscale'       => $ws,
-                  'color'        => sprintf('%02x%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256)),int(rand(256))),
-                  'text'         => 'GFB',
-                  'bounding_box' => 1,
-                  'center'       => 3
+                'y'            => $y,
+                'height'       => $h,
+                'wscale'       => $ws,
+                'color'        => sprintf('%02x%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256)),int(rand(256))),
+                'text'         => 'GFB',
+                'bounding_box' => 1,
+                'center'       => 3
             }
         );
         if (defined($b)) {
@@ -535,10 +547,11 @@ while (time < $s) {
         }
     } ## end while (time < $g)
 }
+
 print_it($F, 'Testing flood fill');
 if ($XX > 255) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->polygon({'coordinates' => [220 * $xm, 190 * $ym, 1520 * $xm, 80 * $xm, 1160 * $xm, $YY, 960 * $xm, 540 * $ym, 760 * $xm, 1080 * $ym]});
+    $F->polygon({'coordinates' => [220 * $xm, 190 * $ym, 1520 * $xm, 80 * $xm, 1160 * $xm, $YY, 960 * $xm, 540 * $ym, 760 * $xm, 780 * $ym]});
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->polygon({'coordinates' => [1270 * $xm, 570 * $ym, 970 * $xm, 170 * $ym, 600 * $xm, 500 * $ym]});
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
@@ -573,11 +586,11 @@ while (time < $s) {
     $F->replace_color(
         {
             'old_red'   => $r,
-              'old_green' => $g,
-              'old_blue'  => $b,
-              'new_red'   => $R,
-              'new_green' => $G,
-              'new_blue'  => $B
+            'old_green' => $g,
+            'old_blue'  => $b,
+            'new_red'   => $R,
+            'new_green' => $G,
+            'new_blue'  => $B
         }
     );
     ($r, $g, $b) = ($R, $G, $B);
@@ -612,32 +625,46 @@ while (time < $s) {
 
 print_it($F, 'Testing Image load (different sizes)');
 
-$s = time + $factor;
-while (time < $s) {
+{
+    my $blank;
+    $s = time + $factor;
+    while (time < $s) {
+        my $image = $F->load_image(
+            {
+                'x'      => 0,
+                'y'      => 0,
+                'width'  => rand($XX),
+                'height' => rand($YY - $F->{'Y_CLIP'}),
+                'center' => 3,
+                'file'   => 'images/GFB.png'
+            }
+        );
+        if (defined($blank)) {
+            $F->xor_mode();
+            $F->blit_write($blank);
+            $F->normal_mode();
+        }
+        $F->blit_write($image);
+        %{$blank} = %{$image};
+    } ## end while (time < $s)
     my $image = $F->load_image(
         {
             'x'      => 0,
             'y'      => 0,
-            'width'  => rand($XX),
-            'height' => rand($YY),
+            'width'  => $XX,
+            'height' => ($YY - $F->{'Y_CLIP'}),
             'center' => 3,
-            'file'   => 'images/testpattern.jpg'
+            'file'   => 'images/GFB.png'
         }
     );
-    $F->blit_write($image);
-} ## end while (time < $s)
-
-$image = $F->load_image(
-    {
-        'x'      => 0,
-        'y'      => 0,
-        'width'  => $XX,
-        'height' => $YY - $F->{'Y_CLIP'},
-        'file'   => 'images/testpattern.jpg'
+    if (defined($blank)) {
+        $F->xor_mode();
+        $F->blit_write($blank);
+        $F->normal_mode();
     }
-);
-$F->blit_write($image);
-sleep 1;
+    $F->blit_write($image);
+    sleep $factor;
+}
 
 print_it($F, 'Testing Image blitting');
 
@@ -647,7 +674,7 @@ $image = $F->load_image(
         'y'      => 0,
         'width'  => int($XX/3),
         'height' => int($YY/3),
-        'file'   => 'images/RWBY_Logo.jpg'
+        'file'   => 'images/RWBY_Logo.png'
     }
 );
 $s = time + $factor;
@@ -673,64 +700,68 @@ if ($YY<=192) {
         {
             'x'      => 0,
             'y'      => 0,
-            'width'  => int($XX/3),
-            'height' => int($YY/3),
+            'width'  => int($XX * .4),
+            'height' => int($YY * .4),
             'file'   => 'images/RWBY_Oh_No.jpg'
         }
     );
 }
 $angle = 0;
-$s = time + ($factor * 2);
-while (time < $s) {
-    my $rot = $F->blit_transform(
-        {
-            'rotate' => {
-                'degrees' => $angle
-            },
-              'blit_data' => $image
-        }
-    );
-    $rot->{'x'} = abs(($XX - $rot->{'width'})/2);
-    $rot->{'y'} = abs(($YY - $rot->{'height'})/2);
-    $F->blit_write($rot);
-    $angle += 5;
-    $angle = 0 if ($angle >= 360);
+{
+    $s = time + ($factor * 2);
+    while (time < $s) {
+        my $rot = $F->blit_transform(
+            {
+                'rotate' => {
+                    'degrees' => $angle
+                },
+                'blit_data' => $image
+            }
+        );
+        $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
+        $rot->{'y'} = abs(($YY - $rot->{'height'}) / 2);
+
+        $F->blit_write($rot);
+
+        $angle += 5;
+        $angle = 0 if ($angle >= 360);
+    }
+}
+$angle = 0;
+{
+    $s = time + ($factor * 2);
+    while (time < $s) {
+        my $rot = $F->blit_transform(
+            {
+                'rotate' => {
+                    'degrees' => $angle
+                },
+                'blit_data' => $image
+            }
+        );
+        $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
+        $rot->{'y'} = abs(($YY - $rot->{'height'}) / 2);
+
+        $F->blit_write($rot);
+
+        $angle -= 5;
+        $angle = 0 if ($angle <= -360);
+    }
 }
 
-if ($XX<=256) {
-    $image = $F->load_image(
-        {
-            'x'      => 0,
-            'y'      => 0,
-            'width'  => $XX,
-            'height' => $YY,
-            'file'   => 'images/RWBY_Faces.png'
-        }
-    );
-} else {
-    $image = $F->load_image(
-        {
-            'x'      => 0,
-            'y'      => 0,
-            'width'  => int($XX/3),
-            'height' => int($YY/3),
-            'file'   => 'images/RWBY_Faces.png'
-        }
-    );
-}
-$s = time + $factor;
-$angle = 0; # Just re-using this variable
-$image = $F->blit_transform(
+$image = $F->load_image(
     {
-        'scale' => {
-            'width' => int($XX * .6),
-            'height' => int($YY * .6)
-        },
-        'blit_data' => $image
+        'x'      => 0,
+        'y'      => 0,
+        'width'  => $XX,
+        'height' => $YY,
+        'file'   => 'images/RWBY_Faces.png'
     }
 );
+$s = time + $factor;
+$angle = 0; # Just re-using this variable
 while (time < $s) {
-    foreach my $dir (qw(normal horizontal normal vertical)) {
+    foreach my $dir (qw(normal horizontal normal vertical normal both)) {
         my $rot = $F->blit_transform(
             {
                 'flip'      => $dir,
@@ -741,14 +772,22 @@ while (time < $s) {
         $rot->{'y'} = abs(($YY - $rot->{'height'}) / 2);
         print_it($F, "Testing Image flip $dir");
         $F->blit_write($rot);
-        sleep .5 unless($angle);
+        sleep .3;
     }
-    $angle++;
 }
 # sleep $factor;
 
 print_it($F, 'Testing Monochrome Image blitting');
 
+$image = $F->blit_transform(
+    {
+        'scale' => {
+            'width'  => int($XX * .6),
+            'height' => int($YY * .6)
+        },
+        'blit_data' => $image
+    }
+);
 $image->{'image'} = $F->monochrome({'image' => $image->{'image'}, 'bits' => $F->{'BITS'}});
 $s = time + $factor;
 while (time < $s) {
@@ -757,56 +796,189 @@ while (time < $s) {
     $F->blit_write($image);
 }
 
-opendir(my $DIR,'images/');
-chomp(my @list = readdir($DIR));
-closedir($DIR);
-@list = shuffle(@list);
-foreach my $info (@list) {
-    next unless ($info =~ /\.gif$/i);
-    for $angle (0 .. 1) {
-        if ($angle || $XX <= 256) {
-            print_it($F, "Testing Animated Image Display of '$info' fullscreen");
-            $image = $F->load_image(
-                {
-                    'width'  => $XX,
-                    'height' => $YY - $F->{'Y_CLIP'},
-                    'file'   => "images/$info",
-                    'center' => 3
+{
+    opendir(my $DIR,'images/');
+    chomp(my @list = readdir($DIR));
+    closedir($DIR);
+    @list = shuffle(@list);
+    foreach my $info (@list) {
+        next unless ($info =~ /\.gif$/i);
+        foreach my $bench (0 .. 1) {
+            for $angle (0 .. 1) {
+                if ($angle || $XX <= 256) {
+                    print_it($F, $bench ? "Testing Animated Image Display of '$info' Fullscreen Benchmark" : "Testing Animated Image Display of '$info' Fullscreen");
+                    $image = $F->load_image(
+                        {
+                            'width'  => $XX,
+                            'height' => $YY - $F->{'Y_CLIP'},
+                            'file'   => "images/$info",
+                            'center' => 3
+                        }
+                    );
+                } else {
+                    print_it($F, $bench ? "Testing Animated Image Display of '$info' Native Size Benchmark" : "Testing Animated Image Display of '$info' Native Size");
+                    $image = $F->load_image(
+                        {
+                            'file'   => "images/$info",
+                            'center' => 3
+                        }
+                    );
                 }
-            );
-        } else {
-            print_it($F, "Testing Animated Image Display of '$info' at native size");
-            $image = $F->load_image(
-                {
-                    'file'   => "images/$info",
-                    'center' => 3
-                }
-            );
-        }
-        $s = time + ($factor);
-        if (defined($image)) {
-            $F->cls();
-            while (time <= $s) {
-                foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
-                    if (time > ($s * 3)) {
-                        print_it($F, 'Your System is Too Slow To Complete The Animation','FF9999FF');
-                        sleep 2;
-                        last;
-                    }
-                    $F->blit_write($image->[$frame]);
-                    my $delay = (($image->[$frame]->{'tags'}->{'gif_delay'} * .01));
-                    if ($delay > 0) {
-                        sleep $delay;
+                if (defined($image)) {
+                    $F->cls();
+                    my $fps   = 0;
+                    my $start = time;
+                    $s = time + ($factor);
+                    while (time <= $s) {
+                        foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
+                            if (time > ($s * 3)) {
+                                print_it($F, 'Your System is Too Slow To Complete The Animation','FF9999FF');
+                                sleep 2;
+                                last;
+                            }
+                            my $begin = time;
+                            $F->blit_write($image->[$frame]);
+                            my $delay = (($image->[$frame]->{'tags'}->{'gif_delay'} * .01)) - (time - $begin);
+                            if ($delay > 0 && !$bench) {
+                                sleep $delay;
+                            }
+                            $fps++;
+                            my $end = time - $start;
+                            if ($end >= 1 && $bench) {
+                                print STDERR "\r",sprintf('%.02f FPS',(1 / $end) * $fps);$|=1;
+                                $fps = 0;
+                                $start = time;
+                            }
+                        }
                     }
                 }
+                last if ($XX <= 256);
             }
         }
-        last if ($XX <= 256);
     }
 }
+
+
+{
+    print_it($F, 'Testing OR Drawing Mode');
+
+    $F->or_mode();
+    my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
+    my $mid  = int($XX / 2);
+
+    $F->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
+    $F->circle({'x' => $mid - ($size / 2),'y'=> $F->{'Y_CLIP'} + $size*2,'radius' => $size, 'filled' => 1});
+    $F->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
+    $F->circle({'x' => $mid,'y'=> $F->{'Y_CLIP'} + $size,'radius' => $size, 'filled' => 1});
+    $F->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
+    $F->circle({'x' => $mid + ($size / 2),'y'=> $F->{'Y_CLIP'} + $size * 2,'radius' => $size, 'filled' => 1});
+    sleep $factor;
+}
+
+{
+    print_it($F, 'Testing XOR Drawing Mode');
+
+    $F->xor_mode();
+    my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
+    my $mid  = int($XX / 2);
+
+    $F->set_color({'red' => 255, 'green' => 255, 'blue' => 0});
+    $F->circle({'x' => $mid - ($size / 2),'y'=> $F->{'Y_CLIP'} + $size*2,'radius' => $size, 'filled' => 1});
+    $F->set_color({'red' => 0, 'green' => 255, 'blue' => 255});
+    $F->circle({'x' => $mid,'y'=> $F->{'Y_CLIP'} + $size,'radius' => $size, 'filled' => 1});
+    $F->set_color({'red' => 255, 'green' => 0, 'blue' => 255});
+    $F->circle({'x' => $mid + ($size / 2),'y'=> $F->{'Y_CLIP'} + $size * 2,'radius' => $size, 'filled' => 1});
+    sleep $factor;
+}
+
+{
+    print_it($F, 'Testing AND Drawing Mode');
+
+    $F->set_color({'red' => 100, 'green' => 100, 'blue' => 100});
+    $F->box({'x' => 0, 'y' => $F->{'Y_CLIP'}, 'xx' => $XX,'yy' => $YY, 'filled' => 1});
+    $F->and_mode();
+    my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
+    my $mid  = int($XX / 2);
+
+    $F->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
+    $F->circle({'x' => $mid - ($size / 2),'y'=> $F->{'Y_CLIP'} + $size*2,'radius' => $size, 'filled' => 1});
+    $F->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
+    $F->circle({'x' => $mid,'y'=> $F->{'Y_CLIP'} + $size,'radius' => $size, 'filled' => 1});
+    $F->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
+    $F->circle({'x' => $mid + ($size / 2),'y'=> $F->{'Y_CLIP'} + $size * 2,'radius' => $size, 'filled' => 1});
+    sleep $factor;
+}
+
+{
+    print_it($F, 'Testing MASK Drawing Mode');
+    my $h = int($YY - $F->{'Y_CLIP'});
+    my $image1 = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => $F->{'Y_CLIP'},
+            'width'  => $XX,
+            'height' => $h,
+            'file'   => 'images/GFB.png',
+            'center' => 1
+        }
+    );
+    my $image2 = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => $F->{'Y_CLIP'},
+            'width'  => $XX,
+            'height' => $h,
+            'file'   => 'images/RWBY_beuowolf.jpg',
+            'center' => 3
+        }
+    );
+    $F->blit_write($image1);
+#    my $p = $F->pixel({'x'=>5,'y'=>$F->{'Y_CLIP'} + 5});print STDERR Dumper($p);sleep 50;
+
+    $F->mask_mode();
+    $F->blit_write($image2);
+    sleep $factor;
+}
+
+{
+    print_it($F, 'Testing UNMASK Drawing Mode');
+    my $h = int($YY - $F->{'Y_CLIP'});
+    my $image1 = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => $F->{'Y_CLIP'},
+            'width'  => $XX,
+            'height' => $h,
+            'file'   => 'images/RWBY_beuowolf.jpg',
+            'center' => 1
+        }
+    );
+    my $image2 = $F->load_image(
+        {
+            'x'      => 0,
+            'y'      => $F->{'Y_CLIP'},
+            'width'  => $XX,
+            'height' => $h,
+            'file'   => 'images/RWBY_Alternate_Logo.png',
+            'center' => 1
+        }
+    );
+    $F->blit_write($image1);
+    $F->unmask_mode();
+    $F->blit_write($image2);
+    sleep $factor;
+}
+
 $F->clip_reset();
 $F->cls('ON');
 
+print STDERR qq{
+
+Yes, I happen to absolutely enjoy the RWBY Anime Series
+by Rooster Teeth Productions, a purely American Anime.
+
+};
+
 exit(0);
 
 sub print_it {
