@@ -11,7 +11,8 @@ use threads;
 use threads::shared;
 
 use Graphics::Framebuffer;
-use Time::HiRes qw(sleep);
+use Time::HiRes qw(sleep time);
+use List::Util qw(shuffle);
 # use Data::Dumper::Simple;
 
 my $args = join('',@ARGV);
@@ -37,11 +38,13 @@ my $RUNNING : shared = 1;
 $SIG{'QUIT'} = sub {
     print STDERR "\nExiting..\n";
     $RUNNING = 0;
+    sleep 1;
     $SIG{'QUIT'} = sub {exit(1);};
 };
 $SIG{'INT'} = sub {
     print STDERR "\nExiting..\n";
     $RUNNING = 0;
+    sleep 1;
     $SIG{'INT'} = sub {exit(1);};
 };
 
@@ -103,19 +106,20 @@ sub gather {
             push(@pics,"$path/$file");
         }
     }
+    @pics = shuffle(@pics);
 }
 
 sub show {
     my $FB = shift;
     my $p  = shift;
+    my $idx = 0;
     while ($RUNNING) {
-        my $name = $pics[int(rand($p))];
+        my $name = $pics[$idx];
         print_it($FB,"Loading image $name");
         my $image;
         unless ($fullscreen) {
             $image = $FB->load_image(
                 {
-                    'noscale'    => 1,
                     'file'       => $name,
                     'center'     => $FB->{'CENTER_XY'},
                     'autolevels' => $auto
@@ -137,26 +141,14 @@ sub show {
         if (defined($image)) {
             $FB->cls();
             if (ref($image) eq 'ARRAY') {
-                my $s = time + 6;
+                my $s = time + 8;
                 while (time <= $s) {
                     last unless($RUNNING);
                     foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
                         last unless($RUNNING);
-                        if (0&&$frame) {
-                            $FB->blit_write(
-                                $FB->blit_transform(
-                                    {
-                                        'blit_data' => $image->[$frame],
-                                        'merge' => {
-                                            'dest_blit_data' => $FB->blit_read($image->[$frame])
-                                        }
-                                    }
-                                )
-                            );
-                        } else {
-                            $FB->blit_write($image->[$frame]);
-                        }
-                        my $delay = ($image->[$frame]->{'tags'}->{'gif_delay'} / 100);
+                        my $begin = time;
+                        $FB->blit_write($image->[$frame]);
+                        my $delay = ($image->[$frame]->{'tags'}->{'gif_delay'} / 100) - (time - $begin);
                         sleep $delay if ($delay > 0);
                     }
                 }
@@ -166,6 +158,8 @@ sub show {
                 sleep 3;
             }
         }
+        $idx++;
+        $idx = 0 if ($idx >= $p);
     }
 }
 
